@@ -13,7 +13,7 @@ from metaflow.exception import MetaflowNotFound,\
 from metaflow.metadata import LocalMetadataProvider, METADATAPROVIDERS
 from metaflow.plugins import ENVIRONMENTS
 
-from metaflow.util import property_once, resolve_identity
+from metaflow.util import cached_property, resolve_identity
 
 from .filecache import FileCache
 
@@ -198,7 +198,6 @@ class MetaflowObject(object):
         self._created_at = time.strftime(
             '%Y-%m-%dT%H:%M:%S.%fZ', time.gmtime(self._object['ts_epoch']//1000))
 
-        self._df = DATAFRAME_VIEWS[self._NAME](self)
         self._tags = frozenset(chain(self._object.get('system_tags') or [],
                                      self._object.get('tags') or []))
 
@@ -303,13 +302,6 @@ class MetaflowObject(object):
         """
         return self._tags
 
-    @property
-    def df(self):
-        """
-        Access Pandas data frames related to this object.
-        """
-        return self._df
-
     @property
     def created_at(self):
         """
@@ -334,7 +326,7 @@ class MetaflowObject(object):
         """
         return '/'.join(self.path_components)
 
-    @property_once
+    @property
     def path_components(self):
         """
         Return a list of IDs corresponding to the path to get to this
@@ -485,7 +477,7 @@ class Task(MetaflowObject):
         # exclude private data artifacts
         return x.id[0] != '_'
 
-    @property_once
+    @property
     def metadata(self):
         """
         Return a list of metadata events produced by this task.
@@ -498,7 +490,7 @@ class Task(MetaflowObject):
                          type=obj.get('type'),
                          task=self) for obj in all_metadata]
 
-    @property_once
+    @property
     def metadata_dict(self):
         """
         Return a dictionary of metadata events produced by this task. If
@@ -508,7 +500,7 @@ class Task(MetaflowObject):
         return {m.name: m.value
                 for m in sorted(self.metadata, key=lambda m: m.created_at)}
 
-    @property_once
+    @property
     def index(self):
         """
         Return the index of the innermost foreach loop, if this
@@ -520,7 +512,7 @@ class Task(MetaflowObject):
         except KeyError:
             return None
 
-    @property_once
+    @property
     def data(self):
         """
         Return a container of data artifacts produced by this task.
@@ -542,7 +534,7 @@ class Task(MetaflowObject):
         obj = namedtuple('MetaflowArtifacts', [art.id for art in self])
         return obj._make(arts)
 
-    @property_once
+    @property
     def successful(self):
         """
         Return `True` if the task finished successfully, `False` otherwise.
@@ -552,7 +544,7 @@ class Task(MetaflowObject):
         except KeyError:
             return False
 
-    @property_once
+    @property
     def finished(self):
         """
         Return `True` if the task has finished, `False` otherwise.
@@ -562,7 +554,7 @@ class Task(MetaflowObject):
         except KeyError:
             return False
 
-    @property_once
+    @property
     def exception(self):
         """
         Return the exception that caused this task to fail. Return
@@ -573,7 +565,7 @@ class Task(MetaflowObject):
         except KeyError:
             return None
 
-    @property_once
+    @property
     def finished_at(self):
         """
         Return a `datetime` object representing the finish time of
@@ -611,7 +603,7 @@ class Task(MetaflowObject):
         logtype = 'stderr'
         return self._load_log(logtype)
 
-    @property_once
+    @cached_property
     def code(self):
         """
         Return a code package, if available, that was used to execute this task.
@@ -620,7 +612,7 @@ class Task(MetaflowObject):
         if code_package:
             return MetaflowCode(self.path_components[0], code_package)
 
-    @property_once
+    @cached_property
     def environment_info(self):
         """
         Return information regarding the environment for this task
@@ -660,7 +652,7 @@ class Step(MetaflowObject):
     _NAME = 'step'
     _CHILD_CLASS = Task
 
-    @property_once
+    @property
     def task(self):
         """
         Return a `Task` object related to this step. This property
@@ -677,7 +669,7 @@ class Step(MetaflowObject):
         """
         return self._filtered_children(*tags)
 
-    @property_once
+    @property
     def finished_at(self):
         """
         Return a `datetime` object representing the finish time of
@@ -687,7 +679,7 @@ class Step(MetaflowObject):
         """
         return max(task.finished_at for task in self)
 
-    @property_once
+    @property
     def environment_info(self):
         """
         Return information regarding the environment for this step
@@ -740,7 +732,7 @@ class Run(MetaflowObject):
         if end:
             return end.data
 
-    @property_once
+    @property
     def successful(self):
         """
         Return `True` if this run was successful, `False` otherwise.
@@ -752,7 +744,7 @@ class Run(MetaflowObject):
         else:
             return False
 
-    @property_once
+    @property
     def finished(self):
         """
         Return `True` if this run has finished, `False` otherwise.
@@ -764,7 +756,7 @@ class Run(MetaflowObject):
         else:
             return False
 
-    @property_once
+    @property
     def finished_at(self):
         """
         Return a `datetime` object representing the finish time of
@@ -774,7 +766,7 @@ class Run(MetaflowObject):
         if end:
             return end.finished_at
 
-    @property_once
+    @property
     def end_task(self):
         """
         Return the `Task` object corresponding to the end step of this
@@ -803,7 +795,7 @@ class Flow(MetaflowObject):
     def __init__(self, *args, **kwargs):
         super(Flow, self).__init__(*args, **kwargs)
 
-    @property_once
+    @property
     def latest_run(self):
         """
         Return the latest run of this flow.
@@ -814,7 +806,7 @@ class Flow(MetaflowObject):
         for run in self:
             return run
 
-    @property_once
+    @property
     def latest_successful_run(self):
         """
         Return the latest successful run of this flow.
